@@ -1,5 +1,8 @@
+# $File: //depot/RT/osf/lib/RTx/Foundry.pm $ $Author: autrijus $
+# $Revision: #15 $ $Change: 10088 $ $DateTime: 2004/02/18 00:22:05 $
+
 package RTx::Foundry;
-$RTx::Foundry::VERSION = '0.00_22';
+$RTx::Foundry::VERSION = '0.01';
 
 1;
 
@@ -9,29 +12,23 @@ RTx::Foundry - Base classes for the RT Foundry system
 
 =head1 VERSION
 
-This document describes version 0.00_22 of RTx::Foundry, released
-December 1, 2004.
+This document describes version 0.01 of RTx::Foundry, released
+March 28, 2004.
 
 =head1 SYNOPSIS
 
 Not at the moment.  See L<http://rt.openfoundry.org/> for a demo.
 
+Currently, the only way to install RT Foundry is from the ports files in
+L<http://rt.openfoundry.org/Foundry/Project/Download/?Queue=OpenFoundry>,
+which requires a FreeBSD system to run on.
+
 =head1 DESCRIPTION
 
-The RT Foundry project is the code behind Taiwan's B<OSSF> initiative,
-as part of the Free Software Promotion Project executed by the Institute of
+The B<RT Foundry> project is the code behind Taiwan's B<OSSF> initiative,
+as part of the Free Software Promotion Project, executed by the Institute of
 Information Science, Academia Sinica (IIS).
 
-The initial goal of RT Foundry is to become the leading project in
-Taiwan to accumulate experience and knowledge of free software and open
-source code, and to establish a software program development website that
-can become a foundation platform for promoting free software. 
-
-The project will also organize local workshops and forums, and publish
-documents such as website manuals, translated terms and vocabulary,
-information on local free software talents and community events,
-comparison of common free software licenses, and Free Software FAQ. 
-
 =head1 DESIGN
 
 This is a very rough outline.  More information will be translated from
@@ -39,7 +36,7 @@ Chinese in due time.
 
 =head2 Overview
 
-What is RT Foundry?
+What is "RT Foundry"?
 
  - Decentralized development environment
  - Modular services
@@ -229,7 +226,7 @@ Current status
   - RTx::Foundry
   - RTx::TabbedUI
   - RTx::Report
- - FreeBSD port (www/openfoundry/) imminent
+ - FreeBSD port (www/rtfoundry/) imminent
 
 Future Plans
 
@@ -242,7 +239,7 @@ Future Plans
 
 =head1 SEE ALSO
 
-RT Foundry Demo: L<http://rt.openfoundry.org/>
+RTx::Foundry Demo: L<http://rt.openfoundry.org/>
 
 OSSF Website: L<http://www.openfoundry.org/en/>
 
@@ -265,15 +262,15 @@ This project is sponsored by:
 Implemented by:
     OurInternet, Inc.
 
-Based on works contributed from:
+Based on works contributed by:
     104 Technology, Inc.
 
-With collaborations from:
-    Best Practical, LLC.
+In collaboration with:
+    Best Practical Solutions, LLC.
 
 =head1 COPYRIGHT
 
-Copyright 2003, 2004 by Academia Sinica, Taiwan.
+Copyright 2004 by Academia Sinica, Taiwan.
 
 (Except where explicitly superseded by other copyright notices)
 
